@@ -44,9 +44,9 @@
 #define TITRAQ_PREFUSER         "user"
 #define TITRAQ_DEFUSER          "username"
 #define TITRAQ_PREFASFILE       "asfile"
-#define TITRAQ_DEFASFILE        "/e/dev/as"
+#define TITRAQ_DEFASFILE        "~/.as/events.as"
 #define TITRAQ_PREFACCOUNTS     "accounts"
-#define TITRAQ_DEFACCOUNTS      "/e/dev/as/accounts.txt"
+#define TITRAQ_DEFACCOUNTS      "~/.as/accounts"
 #define TITRAQ_PREFSTYLE        "uistyle"
 #define TITRAQ_PREFVIEW         "view"
 #define TITRAQ_DEFVIEW          "normal"
@@ -108,9 +108,9 @@
 #define TITRAQ_PREFFCOLWIDTH      "finishcolwidth"
 #define TITRAQ_DEFFCOLWIDTH       80
 #define TITRAQ_PREFACOLWIDTH      "amountcolwidth"
-#define TITRAQ_DEFACOLWIDTH       98
+#define TITRAQ_DEFACOLWIDTH       72
 #define TITRAQ_PREFTCOLWIDTH      "taskcolwidth"
-#define TITRAQ_DEFTCOLWIDTH       96
+#define TITRAQ_DEFTCOLWIDTH       148
 #define TITRAQ_PREFREMCOLWIDTH    "remarkcolwidth"
 #define TITRAQ_DEFREMCOLWIDTH     120
 
@@ -133,6 +133,7 @@
 // Other string constants
 #define TITRAQ_DATEZERO         "0000-00-00"
 #define TITRAQ_SEPARATORTOK     " "
+#define TITRAQ_HOMEDIRTOK       "~/"
 #define TITRAQ_SAVEFIRST        "The timesheet contains unsaved changes\nDo you want to save the changes or discard them?"
 #define TITRAQ_OVERWRITE        "A file already exists with the chosen name\nDo you want to overwrite it with new data?"
 
