@@ -49,7 +49,7 @@
 #endif // HAVE_ESOAP
 #ifdef HAVE_MICO
 #include <coss/CosNaming.h>
-#include "asdb.h"               // CORBA stubs and skeletons
+#include "as_stub.h"            // CORBA stubs and skeletons
 #endif // HAVE_MICO
 
 // Icon pixel maps
